boofun.analysis.sampling
========================

.. automodule:: boofun.analysis.sampling


   .. rubric:: Functions

   .. autosummary::

      estimate_expectation
      estimate_fourier_coefficient
      estimate_influence
      estimate_total_influence
      estimate_variance
      sample_biased
      sample_input_output_pairs
      sample_spectral
      sample_uniform

   .. rubric:: Classes

   .. autosummary::

      RandomVariableView
      SpectralDistribution
